@@ -51,13 +51,6 @@ logging.basicConfig(level=logging.INFO,
 
 QA_CONFIG_MODULES = [
     'qa_config_height',  # takes 14min in CI
-    'qa_config_height_clean',  # takes 9min in CI
-    # 'qa_config_height_dropout',  # takes 14min in CI
-    # 'qa_config_height_deep_ensemble',  # takes 50min in CI
-    # 'qa_config_height_mcnn',  # takes 19min in CI
-    # 'qa_config_height_filter',
-    'qa_config_weight',  # takes 13min in CI
-    # 'qa_config_weight_dropout',  # takes 13min in CI
 ]
 
 if __name__ == "__main__":
@@ -84,11 +77,12 @@ if __name__ == "__main__":
             initializer = OnlineRunInitializer(data_config, eval_config, RUN)
 
         if is_ensemble_evaluation(model_config):
-            model_base_dir = (REPO_DIR / 'data' / model_config.EXPERIMENT_NAME) if is_offline_run(RUN) else Path('.')
+            model_base_dir = (REPO_DIR / 'data/models'
+                              / model_config.EXPERIMENT_NAME) if is_offline_run(RUN) else Path('.')
             eval_class = EnsembleEvaluation
             descriptor = model_config.EXPERIMENT_NAME
         else:
-            model_base_dir = REPO_DIR / 'data' / model_config.RUN_ID if is_offline_run(RUN) else Path('.')
+            model_base_dir = REPO_DIR / 'data/models' / model_config.RUN_ID if is_offline_run(RUN) else Path('.')
             eval_class = MultiartifactEvaluation if is_multiartifact_evaluation(data_config) else Evaluation
             descriptor = model_config.RUN_ID
         evaluation = eval_class(model_config, data_config, model_base_dir, initializer.dataset_path)
