@@ -17,7 +17,7 @@ from sklearn.metrics import ConfusionMatrixDisplay, confusion_matrix
 import matplotlib
 matplotlib.use('Agg')
 import matplotlib.pyplot as plt  # noqa: E402
-from cgmzscore import Calculator  # noqa: E402
+from cgmzscore.src.main import z_score_wfa, z_score_lhfa  # noqa: E402
 
 from .constants_eval import (  # noqa: E402
     CODE_TO_SCANTYPE, COLUMN_NAME_AGE, COLUMN_NAME_GOODBAD, COLUMN_NAME_SEX, DAYS_IN_YEAR,
@@ -63,7 +63,7 @@ def get_column_list(depthmap_path_list: List[str], prediction: np.ndarray, data_
     for idx, path in enumerate(depthmap_path_list):
         loaded_tuple = pickle.load(open(path, "rb"))  # tuple can have 2 or 3 elements
         targets = loaded_tuple[1]
-        targets = preprocess_targets(targets, data_config.TARGET_INDEXES)
+        targets = preprocess_targets(targets, data_config.TARGET_NAMES)
         target = np.squeeze(targets)
 
         sub_folder_list = path.split('/')
@@ -306,11 +306,10 @@ def draw_stunting_diagnosis(df: pd.DataFrame, png_out_fpath: str):
 
 def calculate_zscore_lhfa(df):
     """lhfa: length/height for age"""
-    cal = Calculator()
 
     def _calc_score(age_in_days, height, sex):
         if MIN_HEIGHT < height <= MAX_HEIGHT and age_in_days <= MAX_AGE:
-            return cal.zScore_lhfa(age_in_days=age_in_days, sex=sex, height=height)
+            return z_score_lhfa(age_in_days=age_in_days, sex=sex, height=height)
 
     def _fct(row):
         return _calc_score(age_in_days=int(row[COLUMN_NAME_AGE]),
@@ -343,11 +342,10 @@ def draw_wasting_diagnosis(df: pd.DataFrame, png_out_fpath: str):
 
 def calculate_zscore_wfa(df):
     """Weight for age"""
-    cal = Calculator()
 
     def utils(age_in_days, weight, sex):
         if age_in_days <= MAX_AGE:
-            return cal.zScore_wfa(age_in_days=age_in_days, sex=sex, weight=weight)
+            return z_score_wfa(age_in_days=age_in_days, sex=sex, weight=weight)
 
     df['Z_actual'] = df.apply(
         lambda row: utils(age_in_days=int(row[COLUMN_NAME_AGE]),
@@ -492,12 +490,12 @@ def tf_load_pickle(path, max_value, data_config):
         depthmap = preprocess_depthmap(depthmap)
         depthmap = depthmap / max_value
         depthmap = tf.image.resize(depthmap, (data_config.IMAGE_TARGET_HEIGHT, data_config.IMAGE_TARGET_WIDTH))
-        targets = preprocess_targets(targets, data_config.TARGET_INDEXES)
+        targets = preprocess_targets(targets, data_config.TARGET_NAMES)
         return depthmap, targets
 
     depthmap, targets = tf.py_function(py_load_pickle, [path, max_value], [tf.float32, tf.float32])
     depthmap.set_shape((data_config.IMAGE_TARGET_HEIGHT, data_config.IMAGE_TARGET_WIDTH, 1))
-    targets.set_shape((len(data_config.TARGET_INDEXES,)))
+    targets.set_shape((len(data_config.TARGET_NAMES)))
     return path, depthmap, targets
 
 
